#!/bin/sh -e

. /usr/share/debconf/confmodule
db_version 2.0
db_capb backup

disclaimer=Quran-Trans

errmsg()
{
    echo >&2 ''
    echo >&2 "$@"
    echo >&2 "try 'dpkg-reconfigure debconf' to select a frontend other than noninteractive"
    echo >&2 ''
}

db_get quran-translation-extras/accepted-$disclaimer
if [ "$RET" = "true" ]; then
    echo "$disclaimer disclaimer has already been accepted" >&2
    exit 0
fi

# facilitate backup capability per debconf-devel(7)
STATE=1
while true; do
    case "$STATE" in
    0)  # ensure going back from disclaimer presentment is harmless
        STATE=1 
        continue
        ;;   
    1)  # present disclaimer
        db_fset quran-translation-extras/present-$disclaimer seen false
        if ! db_input critical quran-translation-extras/present-$disclaimer ; then
            errmsg "$disclaimer disclaimer could not be presented"
	    exit 2
        fi
        db_fset quran-translation-extras/accepted-$disclaimer seen false
        if ! db_input critical quran-translation-extras/accepted-$disclaimer ; then
            errmsg "$disclaimer agree question could not be asked"
	    exit 2
        fi
        ;;      
    2)  # determine users' choice
        db_get quran-translation-extras/accepted-$disclaimer
        if [ "$RET" = "true" ]; then
	    # disclaimer accepted
            exit 0
        fi
        # error on decline disclaimer (give user chance to back up)
        db_input critical quran-translation-extras/error-$disclaimer
        ;;      
    3)  # user has confirmed declining disclaimer
        echo "user did not accept the $disclaimer disclaimer" >&2
        exit 1
        ;;   
    *)  # unknown state
        echo "$disclaimer disclaimer state unknown: $STATE" >&2
        exit 2
        ;;   
    esac
    if db_go; then
        STATE=$(($STATE + 1))
    else
        STATE=$(($STATE - 1))
    fi
done
 


# proper exit (0 or 1) above
errmsg "$disclaimer disclaimer could not be presented / was not accepted"
exit 2
